package com.fjhx.xmhjc.controller.browsing;

import cn.hutool.core.date.DatePattern;
import cn.hutool.core.date.DateUtil;
import cn.hutool.core.util.NumberUtil;
import cn.hutool.core.util.ObjectUtil;
import com.fjhx.xmhjc.entity.browsing.vo.StatisticVo;
import org.springframework.web.bind.annotation.*;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.xmhjc.entity.browsing.vo.BrowsingHistoryVo;
import com.fjhx.xmhjc.entity.browsing.dto.BrowsingHistorySelectDto;
import com.fjhx.xmhjc.entity.browsing.dto.BrowsingHistoryDto;
import com.ruoyi.common.core.domain.BaseSelectDto;
import com.fjhx.xmhjc.service.browsing.BrowsingHistoryService;
import org.springframework.beans.factory.annotation.Autowired;

import java.text.DateFormat;
import java.util.List;

/**
 * <p>
 * 浏览记录 前端控制器
 * </p>
 *
 * @author 
 * @since 2024-05-21
 */
@RestController
@RequestMapping("/browsingHistory")
public class BrowsingHistoryController {

    @Autowired
    private BrowsingHistoryService browsingHistoryService;

    /**
     * 浏览记录列表
     */
    @PostMapping("/list")
    public List<BrowsingHistoryVo> list(@RequestBody BrowsingHistorySelectDto dto) {
        return browsingHistoryService.getList(dto);
    }

    /**
     * 浏览记录分页
     */
    @PostMapping("/page")
    public Page<BrowsingHistoryVo> page(@RequestBody BrowsingHistorySelectDto dto) {
        return browsingHistoryService.getPage(dto);
    }

    /**
     * 浏览记录明细
     */
    @PostMapping("/detail")
    public BrowsingHistoryVo detail(@RequestBody BaseSelectDto dto) {
        return browsingHistoryService.detail(dto.getId());
    }

    /**
     * 浏览记录新增
     */
    @PostMapping("/add")
    public void add(@RequestBody BrowsingHistoryDto browsingHistoryDto) {
        browsingHistoryService.add(browsingHistoryDto);
    }

    /**
     * 浏览记录编辑
     */
    @PostMapping("/edit")
    public void edit(@RequestBody BrowsingHistoryDto browsingHistoryDto) {
        browsingHistoryService.edit(browsingHistoryDto);
    }

    /**
     * 浏览记录删除
     */
    @PostMapping("/delete")
    public void delete(@RequestBody BaseSelectDto dto) {
        browsingHistoryService.delete(dto.getId());
    }

    /**
     * 统计今日，本周，本月，总浏览量
     */
    @PostMapping("/getStatistic")
    public StatisticVo getStatistic(@RequestBody BrowsingHistorySelectDto dto) {
        StatisticVo statisticVo = new StatisticVo();


        dto.setBeginTime(DateUtil.beginOfMonth(DateUtil.date()).toString(DatePattern.NORM_DATETIME_MS_FORMAT));
        dto.setEndTime(DateUtil.endOfMonth(DateUtil.date()).toString(DatePattern.NORM_DATETIME_MS_FORMAT));
        List<BrowsingHistoryVo> list = browsingHistoryService.getList(dto);
        // 今日浏览量
        long count = list.stream().filter(browsingHistoryVo -> DateUtil.isSameDay(browsingHistoryVo.getCreateTime(), DateUtil.date())).count();
        statisticVo.setToday(count);
        // 本周浏览量
        long weekCount = list.stream().filter(browsingHistoryVo -> DateUtil.weekOfYear(DateUtil.date()) == (ObjectUtil.isNull(browsingHistoryVo.getWeek())?0:browsingHistoryVo.getWeek().intValue())).count();
        statisticVo.setWeek(weekCount);
        // 本月浏览量
        long monthCount = list.stream().filter(browsingHistoryVo -> DateUtil.month(DateUtil.date())+1 == (ObjectUtil.isNull(browsingHistoryVo.getMonth())?0:browsingHistoryVo.getMonth().intValue())).count();
        statisticVo.setMonth(monthCount);

        return statisticVo;
    }

    @PostMapping("/classifiedList")
    public Page<BrowsingHistoryVo> classifiedList(@RequestBody BrowsingHistorySelectDto dto) {
        Page<BrowsingHistoryVo> list = browsingHistoryService.getClassifiedList(dto);
        return list;
    }
}
